#Multiple-Scenarios: SSP126, SSP245, SSP585 plot
library(loadeR)
library(ggplot2)
library(RColorBrewer)
library(miceadds)

rm(list=ls()) ; graphics.off() ; gc()

#Working directory
setwd("~/Downloads/")
OUTPUTS <- "~/Downloads/"

#----------------------ANNUAL---------------------#
ssp126 <- load.Rdata2("ensemble_CMIP6_mon_ssp126_Catalonia.Rdata")
ssp126$Scenario <- "ssp126"
ssp245 <- load.Rdata2("ensemble_CMIP6_mon_ssp245_Catalonia.Rdata")
ssp245$Scenario <- "ssp245"
ssp585 <- load.Rdata2("ensemble_CMIP6_mon_ssp585_Catalonia.Rdata")
ssp585$Scenario <- "ssp585"

scenario <- rbind(ssp126,ssp245,ssp585)
region <- c("Catalonia","EuroMediterranean")
r=1
scenario$Scenario <- factor(scenario$Scenario,levels=c("ssp585","ssp245","ssp126"))

png(filename = paste(OUTPUTS,"AnnualIndices_TimeSeries_CMIP6_",region[r],"_Historical+Future.png",sep=""),res=300,width=2000,height=3000)
print(ggplot(data=scenario,aes(x=Year))  + 
        geom_ribbon(aes(ymin=Min,ymax=Max,fill=Scenario),alpha=0.5) + ylab("Index Unit")+
        geom_hline(yintercept=0) + geom_vline(xintercept=2014,linetype="dotted")+
        theme_bw() + facet_wrap(~Index,ncol = 2,scales = "free_y")+ geom_line(aes(y=Serie,col=Scenario))+
        labs(title = paste("Annual ETCCDI precipitation and temperature indices over ",region[r],sep=""),
             subtitle = paste("CMIP6 Historical + Future",". Changes wrt 1981-2010",sep="")) +
        scale_color_manual(values=brewer.pal(3,"Set1"),aesthetics = c("colour","fill")))
dev.off()



  
  #----------------------SEASONAL---------------------#
  load(paste("series.indices.mon.CMIP6.",scenario[sc],".Rdata",sep="")) #ssp585
  indices <- c("txx","txn","tnx","tnn","tx90p","tx10p","tn90p","tn10p",
               "rx5day","rx1day")
  
  test <- list()
  for(i in 1:length(indices)){
    test[[i]] <- list()
    for(m in 1:length(series.indices[[i]])){
      test[[i]][[m]] <- do.call("rbind",series.indices[[i]][[m]])
    }
  }
  
  test2 <- list()
  for(i in 1:length(indices)){
    test2[[i]] <- do.call("rbind",test[[i]])
  }
  
  test3 <- do.call("rbind",test2)
  
  Model <- unique(test3$Model)
  Model <- Model[order(Model)]
  
  test3$Model <- factor(test3$Model,levels=rev(Model))
  test3$Index <- toupper(test3$Index)
  test3$Index <- factor(test3$Index,levels=toupper(c("txx","txn","tnx","tnn","tx90p","tx10p","tn90p","tn10p",
                                                     "rx5day","rx1day")))
  
  region <- unique(test3$Region)
  for(r in 1:2){
    #Ensemble
    data <- test3[which(test3$Region==region[r]),]
    
    #Plot by season
    ssn <- c("Winter","Spring","Summer","Autumn")#,"Annual")
    
    for(i in 1:4){
      data2 <- data[which(data$Season==ssn[i]),]
      ensemble <- aggregate(Serie~Index+Year,data2,FUN="mean",na.rm=T)
      ensemble$Min <- ensemble$Serie - aggregate(Serie~Index+Year,data2,FUN="sd",na.rm=T)$Serie
      ensemble$Max <- ensemble$Serie + aggregate(Serie~Index+Year,data2,FUN="sd",na.rm=T)$Serie
      ensemble$Scenario <- scenario[sc]
      
      save(ensemble,file=paste(OUTPUTS,"ensemble_CMIP6_mon_",scenario[sc],"_",ssn[i],"_",region[r],".Rdata",sep=""))
      
      #Temperature indices
      ensemble2 <- subset(ensemble,Index%in%toupper(c("txx","txn","tnx","tnn","tx90p","tx10p","tn90p","tn10p")))
      png(filename = paste(OUTPUTS,"SeasonalIndices_TX_TN_",ssn[i],"_TimeSeries_CMIP6_",region[r],"_Historical+",scenario[sc],".png",sep=""),res=300,width=2000,height=3000)
      print(ggplot(data=ensemble2,aes(x=Year))  + 
              geom_ribbon(aes(ymin=Min,ymax=Max),fill="lightblue") + ylab("Index Unit")+
              geom_hline(yintercept=0) + geom_vline(xintercept=2014,linetype="dotted")+
              theme_bw() + facet_wrap(~Index,ncol = 2,scales = "free_y")+ geom_line(aes(y=Serie),col="black")+
              labs(title = paste(ssn[i]," ETCCDI temperature indices over ",region[r],sep=""),
                   subtitle = paste("CMIP6 Historical + ",scenario[sc],". Changes wrt 1981-2010")))
      dev.off()
      
      #Precipitation indices
      ensemble2 <- subset(ensemble,Index%in%toupper(c("rx1day","rx5day","tnx","tnn","tx90p","tx10p","tn90p","tn10p")))
      png(filename = paste(OUTPUTS,"SeasonalIndices_PR_",ssn[i],"_TimeSeries_CMIP6_",region[r],"_Historical+",scenario[sc],".png",sep=""),res=300,width=2000,height=3000)
      print(ggplot(data=ensemble2,aes(x=Year))  + 
              geom_ribbon(aes(ymin=Min,ymax=Max),fill="lightblue") + ylab("Index Unit")+
              geom_hline(yintercept=0) + geom_vline(xintercept=2014,linetype="dotted")+
              theme_bw() + facet_wrap(~Index,ncol = 2,scales = "free_y")+ geom_line(aes(y=Serie),col="black")+
              labs(title = paste(ssn[i]," ETCCDI precipitation indices over ",region[r],sep=""),
                   subtitle = paste("CMIP6 Historical + ",scenario[sc],". Changes wrt 1981-2010",sep="")))
      dev.off()
    }
    
    #Plot all seasons
    seasons <- list()
    
    for(s in 1:4){
      data2 <- data[which(data$Season==ssn[s]),]
      ensemble <- aggregate(Serie~Index+Year,data2,FUN="mean",na.rm=T)
      ensemble$Min <- ensemble$Serie - aggregate(Serie~Index+Year,data2,FUN="sd",na.rm=T)$Serie
      ensemble$Max <- ensemble$Serie + aggregate(Serie~Index+Year,data2,FUN="sd",na.rm=T)$Serie
      ensemble$Season <- ssn[s]
      seasons[[s]] <- ensemble
    }
    
    seasons <- do.call("rbind",seasons)
    seasons$Season <- factor(seasons$Season,levels=c("Summer","Autumn","Winter","Spring"))
    png(filename = paste(OUTPUTS,"SeasonalIndices","_TimeSeries_CMIP6_",region[r],"_Historical+",scenario[sc],".png",sep=""),res=300,width=2000,height=3000)
    print(ggplot(data=seasons,aes(x=Year))  + 
            geom_ribbon(aes(ymin=Min,ymax=Max),fill="lightblue") + ylab("Index Unit")+
            geom_hline(yintercept=0) + geom_vline(xintercept=2014,linetype="dotted")+
            theme_bw() + facet_grid(Index~Season,scales = "free_y")+ geom_line(aes(y=Serie),col="black")+
            labs(title = paste("Seasonal ETCCDI precipitation and temperature indices over ",region[r],sep=""),
                 subtitle = paste("CMIP6 Historical + ",scenario[sc],". Changes wrt 1981-2010",sep="")))
    dev.off()
  }
}
